# Foo

## Living Standard, 1 January 1970

This version:
  http://example.com/foo
Editor:
  Example Editor

COPYRIGHT GOES HERE

## Abstract

Indexing external references

flex container will-change

## Index

https://drafts.csswg.org/css-flexbox-1/#flex-container Referenced in:

- Unnamed section

https://drafts.csswg.org/css-will-change-1/#propdef-will-change Referenced in:

- Unnamed section

### Terms defined by reference

- [css-flexbox-1] defines the following terms:
  - flex container
- [css-will-change-1] defines the following terms:
  - will-change

## References

### Normative References

[CSS-FLEXBOX-1]
  Tab Atkins Jr.; et al. CSS Flexible Box Layout Module Level 1. 19 November 2018. CR. URL: https://www.w3.org/TR/css-flexbox-1/
[CSS-WILL-CHANGE-1]
  Tab Atkins Jr.. CSS Will Change Module Level 1. 3 December 2015. CR. URL: https://www.w3.org/TR/css-will-change-1/